Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CallOpts ¶
type CallOpts struct {
Filename string
FromName string
FromAddr string
Username string
Password string
Hostname string
Port int
UseAuth bool
Concurrent bool
Number int
}
CallOpts a list of flags
type Config ¶
type Config struct {
Host string
Port int
Username string
Password string
FromAddr string
FromName string
Auth bool
}
Config .... Host is the server mail host, IP or address. Port is the listening port. Username and Passwordare required if auth set to true. FromName and FromAddr are standard mailing values and are in the format of FromName: AkronimBlack FromAddr: akronimBlack@hostname.com
type Email ¶
type Email struct {
Subject string `json:"subject"`
Body string `json:"body"`
To []string `json:"to"`
Error error
}
Email email structure expected from a file
type Mailer ¶
type Mailer struct {
// contains filtered or unexported fields
}
Mailer struct
Click to show internal directories.
Click to hide internal directories.